pub struct MockSelfHostedOrganizationLicensesApi {
SelfHostedOrganizationLicensesApi_expectations: MockSelfHostedOrganizationLicensesApi_SelfHostedOrganizationLicensesApi,
}Fields
SelfHostedOrganizationLicensesApi_expectations: MockSelfHostedOrganizationLicensesApi_SelfHostedOrganizationLicensesApiImplementations
Sourceimpl MockSelfHostedOrganizationLicensesApi
impl MockSelfHostedOrganizationLicensesApi
Sourcepub fn checkpoint(&mut self)
pub fn checkpoint(&mut self)
Validate that all current expectations for all methods have been satisfied, and discard them.
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new mock object with no expectations.
This method will not be generated if the real struct
already has a new method. However, it will be
generated if the struct implements a trait with a new
method. The trait’s new method can still be called
like <MockX as TraitY>::new
Sourceimpl MockSelfHostedOrganizationLicensesApi
impl MockSelfHostedOrganizationLicensesApi
Sourcepub fn expect_create_license(&mut self) -> &mut Expectation
pub fn expect_create_license(&mut self) -> &mut Expectation
Create an Expectation for mocking the create_license method
Sourcepub fn expect_sync_license(&mut self) -> &mut Expectation
pub fn expect_sync_license(&mut self) -> &mut Expectation
Create an Expectation for mocking the sync_license method
Sourcepub fn expect_update_license(&mut self) -> &mut Expectation
pub fn expect_update_license(&mut self) -> &mut Expectation
Create an Expectation for mocking the update_license method